@@ -1,18 +1,16 @@
 gini.conc <-
 function (e_ij, e_j) {
-
+ 
   e_i <- sum(e_ij)
 
   e <- sum(e_j)
 
-  if (e_i > e) { return (NA) }
-
   regions <- length(e_ij)
 
   C_j <- vector()
 
   for (r in 1:regions) { 
-    C_j[r] <- (e_ij[r]/e_i)/(e_j[r]/e)
+    C_j[r] <- locq (e_ij[r], e_j[r], e_i, e)   
   }
   
   C_j_sort <- sort(C_j)
